.. :changelog:

History
-------

0.1.1 (2013-12-24)
++++++++++++++++++

* Description attribute added to Pokemon class


0.1.0 (2013-12-23)
++++++++++++++++++

* First release on PyPI.
* All PokeAPI resources fully supported and represented in an object-oriented style.
* Easy-to-use API: just one method!
